@@ -33,7 +33,7 @@ class EnvDBResource(object):
 
     @staticmethod
     def statistics_daily_usage(records_sorted):
-        work_time_dict = dict()
+        work_time_dict = list()
         for key,value in  records_sorted.items():
             start_time = None
             work_time_list = list()
@@ -47,10 +47,11 @@ class EnvDBResource(object):
                 elif item[1] == "online":
                     start_time = None
             result = {
-                "usage":sum(work_time_list)/86400,
+                "date": key,
+                "usage":float('%.4f'% (sum(work_time_list)/86400)),
                 "total_time":sum(work_time_list)
             }
-            work_time_dict[key] = result
+            work_time_dict.append(result)
         return work_time_dict
 
     def get_nodes(self):
@@ -81,8 +82,23 @@ class EnvDBResource(object):
         :param ip:
         :return:
         """
-
         records = self._get_node(ip)
         records_dict = self._sort_records_by_date(records)
         work_time_dict = self.statistics_daily_usage(records_dict)
-        return work_time_dict
\ No newline at end of file
+        return work_time_dict
+
+    def set_project_name(self, ip, project_name):
+        """
+        set project name to node
+        :param ip:
+        :param project_name:
+        :return:
+        """
+        cmd = "UPDATE node SET project='{}' where `ip`='{}'".format(project_name, ip)
+        self.sql.cursor.execute(cmd)
+        self.sql.conn.commit()
+#
+# if __name__ == '__main__':
+#     DB = EnvDBResource()
+#     aa = DB.get_node_usage_rate("172.29.131.80")
+#     pass
\ No newline at end of file
